TableOp

Enum TableOp 

pub enum TableOp {
Show 28 variants PushConst(f64), PushIteration, PushCol(usize), PushValueAt { col_idx: usize, iter_delta: i32, }, PushValueAtConstRow { col_idx: usize, const_row: usize, }, Add, Subtract, Multiply, Divide, Modulo, Negate, Power, Abs, Round(i32), RoundUp(i32), RoundDown(i32), Min(u8), Max(u8), Eq, Ne, Lt, Lte, Gt, Gte, Not, Jump(usize), JumpIfZero(usize), JumpIfNotZero(usize),
}
Compact opcodes for table cell evaluation without AST tree recursion

Variants



PushConst(f64)

Push literal constant number onto the stack



PushIteration

Push current $iteration raw integer as f64



PushCol(usize)

Push column from current row in flat_cells



PushValueAt

Push cell from self table at (iteration_raw + iter_delta, col_idx)

Fields

col_idx: usize
iter_delta: i32


PushValueAtConstRow

Push cell from self table at constant row index (e.g. static row 0)

Fields

col_idx: usize
const_row: usize


Add

Basic arithmetic



Subtract



Multiply



Divide



Modulo



Negate



Power



Abs



Round(i32)

Excel rounding



RoundUp(i32)



RoundDown(i32)



Min(u8)

Aggregation



Max(u8)



Eq

Comparison



Ne



Lt



Lte



Gt



Gte



Not

Logical



Jump(usize)

Control flow



JumpIfZero(usize)



JumpIfNotZero(usize)