pub struct TableBytecode {
pub ops: Vec<TableOp>,
}Expand description
Compiled linear bytecode for high-speed inner table cell evaluation
Fields
ops: Vec<TableOp>Implementations
Sourceimpl TableBytecode
impl TableBytecode
Sourcepub unsafe fn execute(
&self,
flat_cells: *const Value,
col_count: usize,
row_offset: usize,
existing_row_count: usize,
total_rows: usize,
iteration_raw: i64,
static_rows: *const Vec<Value>,
col_names: &[String],
) -> Option<f64>
pub unsafe fn execute( &self, flat_cells: *const Value, col_count: usize, row_offset: usize, existing_row_count: usize, total_rows: usize, iteration_raw: i64, static_rows: *const Vec<Value>, col_names: &[String], ) -> Option<f64>
Execute bytecode expression against flat cell buffer in a tight stack loop
Safety
flat_cells must point to a buffer of at least total_rows * col_count Values.
static_rows must point to valid Vec<Value> of previous rows.