pub struct ValidationCache {
pub last_data_str: Option<String>,
pub last_context_str: Option<String>,
pub last_validate_readonly: bool,
pub last_result: Option<ValidationResult>,
pub field_cache: IndexMap<String, CachedFieldValidation>,
}Expand description
Cache for validation results (whole-form and per-field)
Fields
last_data_str: Option<String>Last input data string for whole-form caching
last_context_str: Option<String>Last context string for whole-form caching
last_validate_readonly: boolWhether last whole-form validation validated readonly fields
last_result: Option<ValidationResult>Last full validation result
field_cache: IndexMap<String, CachedFieldValidation>Per-field validation cache
Implementations
Sourceimpl ValidationCache
impl ValidationCache
pub fn new() -> Self
Sourcepub fn get_cached_full_result(
&self,
data: &str,
context: Option<&str>,
validate_readonly: bool,
) -> Option<ValidationResult>
pub fn get_cached_full_result( &self, data: &str, context: Option<&str>, validate_readonly: bool, ) -> Option<ValidationResult>
Check if the full validation result can be returned immediately
Sourcepub fn check_field_cache(
&self,
field_path: &str,
field_data: &Value,
is_hidden: bool,
validate_readonly: bool,
rules: &Value,
) -> Option<Option<ValidationError>>
pub fn check_field_cache( &self, field_path: &str, field_data: &Value, is_hidden: bool, validate_readonly: bool, rules: &Value, ) -> Option<Option<ValidationError>>
Check if a single field has a valid cache entry matching current state
Sourcepub fn update_field(
&mut self,
field_path: String,
field_data: Value,
is_hidden: bool,
validate_readonly: bool,
rules_snapshot: Value,
error: Option<ValidationError>,
)
pub fn update_field( &mut self, field_path: String, field_data: Value, is_hidden: bool, validate_readonly: bool, rules_snapshot: Value, error: Option<ValidationError>, )
Update cache for a single field
Sourcepub fn save_full_result(
&mut self,
data_str: String,
context_str: Option<String>,
validate_readonly: bool,
result: ValidationResult,
)
pub fn save_full_result( &mut self, data_str: String, context_str: Option<String>, validate_readonly: bool, result: ValidationResult, )
Save full validation result
Sourcepub fn invalidate_full_result(&mut self)
pub fn invalidate_full_result(&mut self)
Invalidate whole-result cache (e.g. on partial path validation)